package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.OrhonGtxxMapper;
import com.ruoyi.system.domain.OrhonGtxx;
import com.ruoyi.system.service.IOrhonGtxxService;
import com.ruoyi.common.core.text.Convert;

/**
 * 个体信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2020-07-27
 */
@Service
public class OrhonGtxxServiceImpl implements IOrhonGtxxService 
{
    @Autowired
    private OrhonGtxxMapper orhonGtxxMapper;

    /**
     * 查询个体信息
     * 
     * @param id 个体信息ID
     * @return 个体信息
     */
    @Override
    public OrhonGtxx selectOrhonGtxxById(String id)
    {
        return orhonGtxxMapper.selectOrhonGtxxById(id);
    }

    /**
     * 查询个体信息列表
     * 
     * @param orhonGtxx 个体信息
     * @return 个体信息
     */
    @Override
    public List<OrhonGtxx> selectOrhonGtxxList(OrhonGtxx orhonGtxx)
    {
        return orhonGtxxMapper.selectOrhonGtxxList(orhonGtxx);
    }

    /**
     * 新增个体信息
     * 
     * @param orhonGtxx 个体信息
     * @return 结果
     */
    @Override
    public int insertOrhonGtxx(OrhonGtxx orhonGtxx)
    {

        return orhonGtxxMapper.insertOrhonGtxx(orhonGtxx);
    }

    /**
     * 修改个体信息
     * 
     * @param orhonGtxx 个体信息
     * @return 结果
     */
    @Override
    public int updateOrhonGtxx(OrhonGtxx orhonGtxx)
    {
        return orhonGtxxMapper.updateOrhonGtxx(orhonGtxx);
    }

    /**
     * 删除个体信息对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteOrhonGtxxByIds(String ids)
    {
        return orhonGtxxMapper.deleteOrhonGtxxByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除个体信息信息
     * 
     * @param id 个体信息ID
     * @return 结果
     */
    @Override
    public int deleteOrhonGtxxById(String id)
    {
        return orhonGtxxMapper.deleteOrhonGtxxById(id);
    }
}
